"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var consts_1 = require("../utils/consts");
var imports_1 = require("../utils/imports");
var jestGlobalsImport = function (fileInfo, api) {
    var j = api.jscodeshift;
    var ast = j(fileInfo.source);
    var jestGlobalsUsed = new Set();
    consts_1.JEST_GLOBALS.forEach(function (globalName) {
        if (ast
            .find(j.CallExpression, { callee: { name: globalName } })
            .filter(function (callExpression) { return !callExpression.scope.lookup(globalName); })
            .size() > 0 ||
            ast
                .find(j.MemberExpression, { object: { name: globalName } })
                .filter(function (memberExpression) { return !memberExpression.scope.lookup(globalName); })
                .size() > 0) {
            jestGlobalsUsed.add(globalName);
        }
    });
    var jestGlobalsImports = (0, imports_1.findImports)(j, ast, '@jest/globals');
    var hasJestGlobalsImport = jestGlobalsImports.length > 0;
    var needsJestGlobalsImport = jestGlobalsUsed.size > 0;
    if (!needsJestGlobalsImport) {
        if (!hasJestGlobalsImport)
            return null;
        (0, imports_1.removeRequireAndImport)(j, ast, '@jest/globals');
    }
    else {
        var jestGlobalsImport_1 = hasJestGlobalsImport
            ? jestGlobalsImports.get().value
            : j.importDeclaration([], j.stringLiteral('@jest/globals'));
        var specifiers_1 = jestGlobalsImport_1.specifiers;
        var existingNames_1 = new Set(specifiers_1.map(function (s) { return s.imported.name; }));
        jestGlobalsUsed.forEach(function (jestGlobal) {
            if (!existingNames_1.has(jestGlobal)) {
                specifiers_1.push(j.importSpecifier(j.identifier(jestGlobal)));
            }
        });
        if (!hasJestGlobalsImport) {
            ast.find(j.Program).get('body', 0).insertBefore(jestGlobalsImport_1);
        }
    }
    return ast.toSource({ quote: 'single' });
};
exports.default = jestGlobalsImport;
